Class: Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb

Overview

Options for chart generation.

Defined Under Namespace

Classes: ImageOptions

Instance Attribute Summary collapse

Instance Attribute Details

#image::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions

Returns Optional. When specified, the agent will render generated charts using the provided format. Defaults to no image.

Returns:



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb', line 360

class ChartOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for rendering images of generated charts.
  # @!attribute [rw] no_image
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions::NoImage]
  #     No image.
  #
  #     Note: The following fields are mutually exclusive: `no_image`, `svg`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] svg
  #   @return [::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions::SvgOptions]
  #     SVG format.
  #
  #     Note: The following fields are mutually exclusive: `svg`, `no_image`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class ImageOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # No image.
    class NoImage
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # SVG options.
    class SvgOptions
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end