Class: Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb
Overview
Options for rendering images of generated charts.
Defined Under Namespace
Classes: NoImage, SvgOptions
Instance Attribute Summary collapse
-
#no_image ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions::NoImage
No image.
-
#svg ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions::SvgOptions
SVG format.
Instance Attribute Details
#no_image ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions::NoImage
Returns No image.
Note: The following fields are mutually exclusive: no_image, svg. If a field in that set is populated, all other fields in the set will automatically be cleared.
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb', line 375 class ImageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # No image. class NoImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SVG options. class SvgOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#svg ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions::ImageOptions::SvgOptions
Returns SVG format.
Note: The following fields are mutually exclusive: svg, no_image. If a field in that set is populated, all other fields in the set will automatically be cleared.
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb', line 375 class ImageOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # No image. class NoImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SVG options. class SvgOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |