Class: Google::Cloud::GeminiDataAnalytics::V1beta::ChatRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::ChatRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb
Overview
Request for Chat.
Defined Under Namespace
Modules: Model, ThinkingMode
Instance Attribute Summary collapse
-
#client_managed_resource_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ClientManagedResourceContext
Optional.
-
#conversation_reference ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ConversationReference
Optional.
-
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Credentials
Optional.
-
#data_agent_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataAgentContext
Optional.
-
#inline_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Context
Optional.
-
#looker_settings ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::LookerSettings
Optional.
-
#messages ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::Message>
Required.
-
#model ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChatRequest::Model
Optional.
-
#parent ⇒ ::String
Required.
-
#project ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#thinking_mode ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChatRequest::ThinkingMode
Optional.
Instance Attribute Details
#client_managed_resource_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ClientManagedResourceContext
Returns Optional. Context with client managed resources. Some clients may not use GDA managed resources including conversations and agents, instead they create and manage their own conversations and agents resources.
Note: The following fields are mutually exclusive: client_managed_resource_context, inline_context, conversation_reference, data_agent_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#conversation_reference ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ConversationReference
Returns Optional. Reference to a persisted conversation and agent context. Use this to chat with an Agent using managed conversation persistence.
Note: The following fields are mutually exclusive: conversation_reference, inline_context, data_agent_context, client_managed_resource_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Credentials
Returns Optional. The credentials to use when calling the data source(s) specified in the context.
This field can be used to provide credentials for various data sources. For example, when connecting to Looker, it currently supports both OAuth token and API key-based credentials, as described in Authentication with an SDK.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#data_agent_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataAgentContext
Returns Optional. Context for the chat request. Use this to chat with an Agent statelessly, without managed conversation persistence.
Note: The following fields are mutually exclusive: data_agent_context, inline_context, conversation_reference, client_managed_resource_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#inline_context ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Context
Returns Optional. Inline context for the chat request. Use this to chat statelessly (without managed conversation persistence and without an Agent) by passing all context inline.
Note: The following fields are mutually exclusive: inline_context, conversation_reference, data_agent_context, client_managed_resource_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#looker_settings ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::LookerSettings
Returns Optional. Looker specific settings.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#messages ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::Message>
Returns Required. Content of current conversation.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#model ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChatRequest::Model
Returns Optional. The model to use for the agent loop when processing the request. This setting only has an effect when context.options.model is not set.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#parent ⇒ ::String
Returns Required. The parent value for chat request.
Pattern: projects/{project}/locations/{location}.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#project ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: Use parent field instead.
The Google Cloud project to be used for quota and billing.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |
#thinking_mode ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ChatRequest::ThinkingMode
Returns Optional. The thinking mode to use for the agent loop. Defaults to THINKING_MODE_UNSPECIFIED if not specified.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 305 class ChatRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode of thinking for the agent. module ThinkingMode # Unspecified thinking mode, agent will use THINKING mode by default. THINKING_MODE_UNSPECIFIED = 0 # Fast mode, answers quickly. FAST = 1 # Thinking mode, solves complex problems. THINKING = 2 end # Model selection for the agent. module Model # No model specified. The default model will be used. MODEL_UNSPECIFIED = 0 # Use the most up-to-date non-preview model. This may constrain certain # request level settings. LATEST_GA_MODEL = 1 end end |