Class: Google::Cloud::GeminiDataAnalytics::V1beta::ConversationOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb

Overview

Options for the conversation.

Defined Under Namespace

Modules: Model

Instance Attribute Summary collapse

Instance Attribute Details

#analysis::Google::Cloud::GeminiDataAnalytics::V1beta::AnalysisOptions

Returns Optional. Options for analysis.

Returns:



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb', line 327

class ConversationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Allowed models for the agent/conversation.
  module Model
    # No model specified. The model may be set on the chat request, or the
    # default model will be used.
    MODEL_UNSPECIFIED = 0

    # Use the most up-to-date non-preview model. This may constrain certain
    # request level settings.
    LATEST_GA_MODEL = 1
  end
end

#chart::Google::Cloud::GeminiDataAnalytics::V1beta::ChartOptions

Returns Optional. Options for chart generation.

Returns:



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb', line 327

class ConversationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Allowed models for the agent/conversation.
  module Model
    # No model specified. The model may be set on the chat request, or the
    # default model will be used.
    MODEL_UNSPECIFIED = 0

    # Use the most up-to-date non-preview model. This may constrain certain
    # request level settings.
    LATEST_GA_MODEL = 1
  end
end

#datasource::Google::Cloud::GeminiDataAnalytics::V1beta::DatasourceOptions

Returns Optional. Options for datasources.

Returns:



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb', line 327

class ConversationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Allowed models for the agent/conversation.
  module Model
    # No model specified. The model may be set on the chat request, or the
    # default model will be used.
    MODEL_UNSPECIFIED = 0

    # Use the most up-to-date non-preview model. This may constrain certain
    # request level settings.
    LATEST_GA_MODEL = 1
  end
end

#model::Google::Cloud::GeminiDataAnalytics::V1beta::ConversationOptions::Model

Returns Optional. The model to use for the agent loop.

Returns:



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/context.rb', line 327

class ConversationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Allowed models for the agent/conversation.
  module Model
    # No model specified. The model may be set on the chat request, or the
    # default model will be used.
    MODEL_UNSPECIFIED = 0

    # Use the most up-to-date non-preview model. This may constrain certain
    # request level settings.
    LATEST_GA_MODEL = 1
  end
end