Class: Google::Cloud::GeminiDataAnalytics::V1beta::DataMessage
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::DataMessage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb
Overview
A message produced during data retrieval.
Instance Attribute Summary collapse
-
#big_query_job ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryJob
A BigQuery job executed by the system to retrieve data.
-
#generated_looker_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::LookerQuery
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#generated_sql ⇒ ::String
SQL generated by the system to retrieve data.
-
#matched_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::MatchedQuery
A pre-existing query that was matched to retrieve data.
-
#query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataQuery
A data retrieval query.
-
#result ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataResult
Retrieved data.
Instance Attribute Details
#big_query_job ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryJob
Returns A BigQuery job executed by the system to retrieve data.
Note: The following fields are mutually exclusive: big_query_job, query, generated_sql, result, generated_looker_query, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.
614 615 616 617 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 614 class DataMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#generated_looker_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::LookerQuery
This field is deprecated and may be removed in the next major version update.
Returns Deprecated: generated looker query is now under DataQuery.looker. Looker Query generated by the system to retrieve data.
Note: The following fields are mutually exclusive: generated_looker_query, query, generated_sql, result, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.
614 615 616 617 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 614 class DataMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#generated_sql ⇒ ::String
Returns SQL generated by the system to retrieve data.
Note: The following fields are mutually exclusive: generated_sql, query, result, generated_looker_query, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.
614 615 616 617 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 614 class DataMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#matched_query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::MatchedQuery
Returns A pre-existing query that was matched to retrieve data.
Note: The following fields are mutually exclusive: matched_query, query, generated_sql, result, generated_looker_query, big_query_job. If a field in that set is populated, all other fields in the set will automatically be cleared.
614 615 616 617 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 614 class DataMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataQuery
Returns A data retrieval query.
Note: The following fields are mutually exclusive: query, generated_sql, result, generated_looker_query, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.
614 615 616 617 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 614 class DataMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#result ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataResult
Returns Retrieved data.
Note: The following fields are mutually exclusive: result, query, generated_sql, generated_looker_query, big_query_job, matched_query. If a field in that set is populated, all other fields in the set will automatically be cleared.
614 615 616 617 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 614 class DataMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |