Class: Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb

Overview

The result of a query execution. The design is generic for all dialects.

Defined Under Namespace

Classes: Column, Row, Value

Instance Attribute Summary collapse

Instance Attribute Details

#columns::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult::Column>

Returns The columns in the result set, in order.

Returns:



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 155

class ExecutedQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a single column in the result set.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the column.
  # @!attribute [rw] type
  #   @return [::String]
  #     The type of the column (e.g., "VARCHAR", "INT64", "TIMESTAMP").
  class Column
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single value within a row.
  # @!attribute [rw] value
  #   @return [::String]
  #     The cell value, represented in a string format.
  #     Timestamps could be formatted, for example, using RFC3339Nano.
  #     This field is used if the value is not null.
  class Value
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single row in the result set.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult::Value>]
  #     The values in the row, corresponding positionally to the columns.
  class Row
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#partial_result::Boolean

Returns Set to true if the returned rows in query_result are a subset of the full result. This can happen, for example, if the query execution hits a row limit. When true, the query_result does not contain all rows. To retrieve the complete result, consider using the generated_query in QueryDataResponse and executing it in your own environment.

Returns:

  • (::Boolean)

    Set to true if the returned rows in query_result are a subset of the full result. This can happen, for example, if the query execution hits a row limit. When true, the query_result does not contain all rows. To retrieve the complete result, consider using the generated_query in QueryDataResponse and executing it in your own environment.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 155

class ExecutedQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a single column in the result set.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the column.
  # @!attribute [rw] type
  #   @return [::String]
  #     The type of the column (e.g., "VARCHAR", "INT64", "TIMESTAMP").
  class Column
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single value within a row.
  # @!attribute [rw] value
  #   @return [::String]
  #     The cell value, represented in a string format.
  #     Timestamps could be formatted, for example, using RFC3339Nano.
  #     This field is used if the value is not null.
  class Value
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single row in the result set.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult::Value>]
  #     The values in the row, corresponding positionally to the columns.
  class Row
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#query_execution_error::String

Returns The error message if the query execution failed.

Returns:

  • (::String)

    The error message if the query execution failed.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 155

class ExecutedQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a single column in the result set.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the column.
  # @!attribute [rw] type
  #   @return [::String]
  #     The type of the column (e.g., "VARCHAR", "INT64", "TIMESTAMP").
  class Column
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single value within a row.
  # @!attribute [rw] value
  #   @return [::String]
  #     The cell value, represented in a string format.
  #     Timestamps could be formatted, for example, using RFC3339Nano.
  #     This field is used if the value is not null.
  class Value
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single row in the result set.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult::Value>]
  #     The values in the row, corresponding positionally to the columns.
  class Row
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#rows::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult::Row>

Returns The rows returned by the query.

Returns:



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 155

class ExecutedQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a single column in the result set.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the column.
  # @!attribute [rw] type
  #   @return [::String]
  #     The type of the column (e.g., "VARCHAR", "INT64", "TIMESTAMP").
  class Column
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single value within a row.
  # @!attribute [rw] value
  #   @return [::String]
  #     The cell value, represented in a string format.
  #     Timestamps could be formatted, for example, using RFC3339Nano.
  #     This field is used if the value is not null.
  class Value
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single row in the result set.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult::Value>]
  #     The values in the row, corresponding positionally to the columns.
  class Row
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#total_row_count::Integer

Returns The total number of rows in the full result set, if known. This may be an estimate or an exact count.

Returns:

  • (::Integer)

    The total number of rows in the full result set, if known. This may be an estimate or an exact count.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 155

class ExecutedQueryResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a single column in the result set.
  # @!attribute [rw] name
  #   @return [::String]
  #     The name of the column.
  # @!attribute [rw] type
  #   @return [::String]
  #     The type of the column (e.g., "VARCHAR", "INT64", "TIMESTAMP").
  class Column
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single value within a row.
  # @!attribute [rw] value
  #   @return [::String]
  #     The cell value, represented in a string format.
  #     Timestamps could be formatted, for example, using RFC3339Nano.
  #     This field is used if the value is not null.
  class Value
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents a single row in the result set.
  # @!attribute [rw] values
  #   @return [::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ExecutedQueryResult::Value>]
  #     The values in the row, corresponding positionally to the columns.
  class Row
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end