Class: Google::Cloud::GeminiDataAnalytics::V1beta::GenerationOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb

Overview

Options to control query generation, execution, and response format.

Instance Attribute Summary collapse

Instance Attribute Details

#generate_disambiguation_question::Boolean

Returns Optional. If true (default to false), the service may return a clarifying_question if the input query is ambiguous.

Returns:

  • (::Boolean)

    Optional. If true (default to false), the service may return a clarifying_question if the input query is ambiguous.



62
63
64
65
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 62

class GenerationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#generate_explanation::Boolean

Returns Optional. If true, an explanation of the generated query will be returned in the response.

Returns:

  • (::Boolean)

    Optional. If true, an explanation of the generated query will be returned in the response.



62
63
64
65
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 62

class GenerationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#generate_natural_language_answer::Boolean

Returns Optional. If true, a natural language answer based on the query execution result will be generated and returned in the response.

Returns:

  • (::Boolean)

    Optional. If true, a natural language answer based on the query execution result will be generated and returned in the response.



62
63
64
65
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 62

class GenerationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#generate_query_result::Boolean

Returns Optional. If true, the generated query will be executed, and the result data will be returned in the response.

Returns:

  • (::Boolean)

    Optional. If true, the generated query will be executed, and the result data will be returned in the response.



62
63
64
65
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 62

class GenerationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end