Class: Google::Cloud::GeminiDataAnalytics::V1beta::ListMessagesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::ListMessagesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb
Overview
Request for listing chat messages based on parent and conversation_id.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filtering results. See AIP-160 for syntax.
ListMessages allows filtering by:
- create_time (e.g.,
createTime > "2025-01-28T06:51:56-08:00") - update_time.
215 216 217 218 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 215 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than
requested. The max page size is 100. All larger page sizes will be
coerced to 100. If unspecified, server will pick 50 as an appropriate
default.
215 216 217 218 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 215 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
215 216 217 218 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 215 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The conversation to list messages under.
Format:
projects/{project}/locations/{location}/conversations/{conversation_id}.
215 216 217 218 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 215 class ListMessagesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |