Class: Google::Cloud::GeminiDataAnalytics::V1beta::SpannerDatabaseReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb

Overview

Message representing a reference to a single Spanner database.

Defined Under Namespace

Modules: Engine

Instance Attribute Summary collapse

Instance Attribute Details

#database_id::String

Returns Required. The database id.

Returns:

  • (::String)

    Required. The database id.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end

#database_table_references::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::DatabaseTableReference>

Returns Optional. References to tables within the database. Each reference specifies a table and can optionally include the table's schema to provide context for the query.

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end

#engine::Google::Cloud::GeminiDataAnalytics::V1beta::SpannerDatabaseReference::Engine

Returns Required. The engine of the Spanner instance.

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end

#instance_id::String

Returns Required. The instance id.

Returns:

  • (::String)

    Required. The instance id.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end

#priority::String

Returns Optional. Priority for the queries to Spanner. Should be a value supported by Cloud Spanner e.g.: LOW, MEDIUM, HIGH. Unsupported values will be ignored. See https://docs.cloud.google.com/spanner/docs/reference/rest/v1/RequestOptions#Priority for complete list.

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end

#project_id::String

Returns Required. The project the instance belongs to.

Returns:

  • (::String)

    Required. The project the instance belongs to.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end

#request_tag::String

Returns Tag to be attached to all queries to Spanner. Allows to identify and monitor queries sent to Spanner by the GDA service.

Returns:

  • (::String)

    Tag to be attached to all queries to Spanner. Allows to identify and monitor queries sent to Spanner by the GDA service.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end

#table_ids::Array<::String>

Returns Optional. The table ids. Denotes all tables if unset.

Returns:

  • (::Array<::String>)

    Optional. The table ids. Denotes all tables if unset.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 242

class SpannerDatabaseReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engine.
  module Engine
    # Engine is not specified.
    ENGINE_UNSPECIFIED = 0

    # Google SQL
    GOOGLE_SQL = 1

    # PostgreSQL
    POSTGRESQL = 2
  end
end