Class: Google::Cloud::GeminiDataAnalytics::V1beta::TextMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb

Overview

A multi-part text message.

Defined Under Namespace

Modules: TextType

Instance Attribute Summary collapse

Instance Attribute Details

#parts::Array<::String>

Returns Optional. The parts of the message.

Returns:

  • (::Array<::String>)

    Optional. The parts of the message.



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 519

class TextMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the text message.
  module TextType
    # The default text type.
    TEXT_TYPE_UNSPECIFIED = 0

    # The text is a final response to the user question.
    FINAL_RESPONSE = 1

    # The text is a thought from the model.
    THOUGHT = 2

    # The text is an informational message about the agent's progress, such as
    # a tool being invoked. This is distinct from the agent's internal thought
    # process (`THOUGHT`) and the final answer to the user
    # (`FINAL_RESPONSE`). These messages provide insight into the agent's
    # actions.
    PROGRESS = 3

    # The text is a list of follow-up questions suggested.
    # Each item in parts is a follow-up question.
    FOLLOWUP_QUESTIONS = 4
  end
end

#text_type::Google::Cloud::GeminiDataAnalytics::V1beta::TextMessage::TextType

Returns Optional. The type of the text message.

Returns:



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 519

class TextMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the text message.
  module TextType
    # The default text type.
    TEXT_TYPE_UNSPECIFIED = 0

    # The text is a final response to the user question.
    FINAL_RESPONSE = 1

    # The text is a thought from the model.
    THOUGHT = 2

    # The text is an informational message about the agent's progress, such as
    # a tool being invoked. This is distinct from the agent's internal thought
    # process (`THOUGHT`) and the final answer to the user
    # (`FINAL_RESPONSE`). These messages provide insight into the agent's
    # actions.
    PROGRESS = 3

    # The text is a list of follow-up questions suggested.
    # Each item in parts is a follow-up question.
    FOLLOWUP_QUESTIONS = 4
  end
end

#thought_signature::String

Returns Optional. An opaque signature for a thought so it can be reused in subsequent requests.

Returns:

  • (::String)

    Optional. An opaque signature for a thought so it can be reused in subsequent requests.



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 519

class TextMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the text message.
  module TextType
    # The default text type.
    TEXT_TYPE_UNSPECIFIED = 0

    # The text is a final response to the user question.
    FINAL_RESPONSE = 1

    # The text is a thought from the model.
    THOUGHT = 2

    # The text is an informational message about the agent's progress, such as
    # a tool being invoked. This is distinct from the agent's internal thought
    # process (`THOUGHT`) and the final answer to the user
    # (`FINAL_RESPONSE`). These messages provide insight into the agent's
    # actions.
    PROGRESS = 3

    # The text is a list of follow-up questions suggested.
    # Each item in parts is a follow-up question.
    FOLLOWUP_QUESTIONS = 4
  end
end