Class: Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryTableReferences
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryTableReferences
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb
Overview
Message representing references to BigQuery tables and property graphs.
At least one of table_references, property_graph_references, or
search_scope must be populated.
Instance Attribute Summary collapse
-
#property_graph_references ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryPropertyGraphReference>
Optional.
-
#table_references ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryTableReference>
Optional.
Instance Attribute Details
#property_graph_references ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryPropertyGraphReference>
Returns Optional. Preview feature. References to BigQuery property graphs. Note: Data sources must exclusively use either tables or property graphs, not both. When using property graphs, a maximum of one graph reference is supported.
75 76 77 78 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 75 class BigQueryTableReferences include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#table_references ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::BigQueryTableReference>
Returns Optional. References to BigQuery tables.
75 76 77 78 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 75 class BigQueryTableReferences include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |