Class: Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationMessage Deprecated
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationMessage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb
Overview
Deprecated.
This message is deprecated and may be removed in the next major version update.
Deprecated: Use TextMessage with TextType.FINAL_RESPONSE instead. A message of questions to help clarify the user's query. This is returned when the system cannot confidently answer the user's question.
Instance Attribute Summary collapse
-
#questions ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion>
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#questions ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion>
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Required. Deprecated: The parent message is deprecated. A batch of clarification questions to ask the user.
932 933 934 935 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 932 class ClarificationMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |