Class: Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion Deprecated
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb
Overview
This message is deprecated and may be removed in the next major version update.
Deprecated: Use TextMessage with TextType.FINAL_RESPONSE instead. Represents a single question to the user to help clarify their query.
Defined Under Namespace
Modules: ClarificationQuestionType, SelectionMode
Instance Attribute Summary collapse
-
#clarification_question_type ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion::ClarificationQuestionType
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#options ⇒ ::Array<::String>
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#question ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#selection_mode ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion::SelectionMode
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#clarification_question_type ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion::ClarificationQuestionType
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: The parent message is deprecated. The type of clarification question.
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 881 class ClarificationQuestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deprecated: The parent message is deprecated. # The selection mode for the clarification question. # @deprecated This enum is deprecated and may be removed in the next major version update. module SelectionMode # Deprecated: The parent message is deprecated. # Unspecified selection mode. SELECTION_MODE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The user can select only one option. SINGLE_SELECT = 1 # Deprecated: The parent message is deprecated. # The user can select multiple options. MULTI_SELECT = 2 end # Deprecated: The parent message is deprecated. # The type of clarification question. # This enum may be extended with new values in the future. # @deprecated This enum is deprecated and may be removed in the next major version update. module ClarificationQuestionType # Deprecated: The parent message is deprecated. # Unspecified clarification question type. CLARIFICATION_QUESTION_TYPE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The clarification question is for filter values. FILTER_VALUES = 1 # Deprecated: The parent message is deprecated. # The clarification question is for data fields. This is a generic term # encompassing SQL columns, Looker fields (dimensions/measures), or # nested data structure properties. FIELDS = 2 end end |
#options ⇒ ::Array<::String>
This field is deprecated and may be removed in the next major version update.
Returns Required. Deprecated: The parent message is deprecated. A list of distinct options for the user to choose from. The number of options is limited to a maximum of 5.
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 881 class ClarificationQuestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deprecated: The parent message is deprecated. # The selection mode for the clarification question. # @deprecated This enum is deprecated and may be removed in the next major version update. module SelectionMode # Deprecated: The parent message is deprecated. # Unspecified selection mode. SELECTION_MODE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The user can select only one option. SINGLE_SELECT = 1 # Deprecated: The parent message is deprecated. # The user can select multiple options. MULTI_SELECT = 2 end # Deprecated: The parent message is deprecated. # The type of clarification question. # This enum may be extended with new values in the future. # @deprecated This enum is deprecated and may be removed in the next major version update. module ClarificationQuestionType # Deprecated: The parent message is deprecated. # Unspecified clarification question type. CLARIFICATION_QUESTION_TYPE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The clarification question is for filter values. FILTER_VALUES = 1 # Deprecated: The parent message is deprecated. # The clarification question is for data fields. This is a generic term # encompassing SQL columns, Looker fields (dimensions/measures), or # nested data structure properties. FIELDS = 2 end end |
#question ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Required. Deprecated: The parent message is deprecated. The natural language question to ask the user.
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 881 class ClarificationQuestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deprecated: The parent message is deprecated. # The selection mode for the clarification question. # @deprecated This enum is deprecated and may be removed in the next major version update. module SelectionMode # Deprecated: The parent message is deprecated. # Unspecified selection mode. SELECTION_MODE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The user can select only one option. SINGLE_SELECT = 1 # Deprecated: The parent message is deprecated. # The user can select multiple options. MULTI_SELECT = 2 end # Deprecated: The parent message is deprecated. # The type of clarification question. # This enum may be extended with new values in the future. # @deprecated This enum is deprecated and may be removed in the next major version update. module ClarificationQuestionType # Deprecated: The parent message is deprecated. # Unspecified clarification question type. CLARIFICATION_QUESTION_TYPE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The clarification question is for filter values. FILTER_VALUES = 1 # Deprecated: The parent message is deprecated. # The clarification question is for data fields. This is a generic term # encompassing SQL columns, Looker fields (dimensions/measures), or # nested data structure properties. FIELDS = 2 end end |
#selection_mode ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::ClarificationQuestion::SelectionMode
This field is deprecated and may be removed in the next major version update.
Returns Required. Deprecated: The parent message is deprecated. The selection mode for this question.
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 881 class ClarificationQuestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deprecated: The parent message is deprecated. # The selection mode for the clarification question. # @deprecated This enum is deprecated and may be removed in the next major version update. module SelectionMode # Deprecated: The parent message is deprecated. # Unspecified selection mode. SELECTION_MODE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The user can select only one option. SINGLE_SELECT = 1 # Deprecated: The parent message is deprecated. # The user can select multiple options. MULTI_SELECT = 2 end # Deprecated: The parent message is deprecated. # The type of clarification question. # This enum may be extended with new values in the future. # @deprecated This enum is deprecated and may be removed in the next major version update. module ClarificationQuestionType # Deprecated: The parent message is deprecated. # Unspecified clarification question type. CLARIFICATION_QUESTION_TYPE_UNSPECIFIED = 0 # Deprecated: The parent message is deprecated. # The clarification question is for filter values. FILTER_VALUES = 1 # Deprecated: The parent message is deprecated. # The clarification question is for data fields. This is a generic term # encompassing SQL columns, Looker fields (dimensions/measures), or # nested data structure properties. FIELDS = 2 end end |