Class: Google::Cloud::GeminiDataAnalytics::V1beta::DataAgentContext
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::DataAgentContext
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb
Overview
Context for the chat request using a data agent.
Defined Under Namespace
Modules: ContextVersion
Instance Attribute Summary collapse
-
#context_version ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataAgentContext::ContextVersion
Optional.
-
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Credentials
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#data_agent ⇒ ::String
Required.
Instance Attribute Details
#context_version ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::DataAgentContext::ContextVersion
Returns Optional. Version of context to be used by DCS (e.g. STAGING, PUBLISHED).
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 349 class DataAgentContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of context versions supported by DCS. # There are two versions of context. This is to maintain versioning for the # data agent. module ContextVersion # Unspecified or unrecognized. CONTEXT_VERSION_UNSPECIFIED = 0 # Using this version, DCS will use the latest staging context for the # data agent. STAGING = 1 # Using this version, DCS will use the latest published context for the # data agent. PUBLISHED = 2 end end |
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Credentials
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: Use credentials in ChatRequest. The credentials to use when calling the Looker data source.
Currently supports both OAuth token and API key-based credentials, as described in Authentication with an SDK.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 349 class DataAgentContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of context versions supported by DCS. # There are two versions of context. This is to maintain versioning for the # data agent. module ContextVersion # Unspecified or unrecognized. CONTEXT_VERSION_UNSPECIFIED = 0 # Using this version, DCS will use the latest staging context for the # data agent. STAGING = 1 # Using this version, DCS will use the latest published context for the # data agent. PUBLISHED = 2 end end |
#data_agent ⇒ ::String
Returns Required. The name of the data agent resource.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/data_chat_service.rb', line 349 class DataAgentContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # List of context versions supported by DCS. # There are two versions of context. This is to maintain versioning for the # data agent. module ContextVersion # Unspecified or unrecognized. CONTEXT_VERSION_UNSPECIFIED = 0 # Using this version, DCS will use the latest staging context for the # data agent. STAGING = 1 # Using this version, DCS will use the latest published context for the # data agent. PUBLISHED = 2 end end |