Class: Google::Cloud::GeminiDataAnalytics::V1beta::LookerExploreReferences
- Inherits:
-
Object
- Object
- Google::Cloud::GeminiDataAnalytics::V1beta::LookerExploreReferences
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb
Overview
Message representing references to Looker explores.
Instance Attribute Summary collapse
-
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Credentials
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#explore_references ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::LookerExploreReference>
Required.
Instance Attribute Details
#credentials ⇒ ::Google::Cloud::GeminiDataAnalytics::V1beta::Credentials
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: Use credentials in ChatRequest. The credentials to use when calling the Looker API.
Currently supports both OAuth token and API key-based credentials, as described in Authentication with an SDK.
328 329 330 331 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 328 class LookerExploreReferences include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#explore_references ⇒ ::Array<::Google::Cloud::GeminiDataAnalytics::V1beta::LookerExploreReference>
Returns Required. References to Looker explores.
328 329 330 331 |
# File 'proto_docs/google/cloud/geminidataanalytics/v1beta/datasource.rb', line 328 class LookerExploreReferences include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |